FlutterPluginRecord class

Constructors

FlutterPluginRecord()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
response → Stream<RecordResponse>
no setter
responseFromAmplitude → Stream<RecordResponse>
no setter
responseFromInit → Stream<bool>
no setter
responsePlayStateController → Stream<PlayState>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
init() → Future
initRecordMp3() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pausePlay() → Future
暂停播放
play() → Future
playByPath(String path, String type) → Future
参数 path 播放音频的地址
start() → Future
startByWavPath(String wavPath) → Future
stop() → Future
stopPlay() → Future
提供停止播放的功能
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

alis → Map<String, FlutterPluginRecord>
final